package com.jz.dm.common.util.stream;


import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.http.*;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.text.MessageFormat;

import static com.jz.common.utils.HttpClientPool.getHttpClient;


/**
 * @author ZC
 * @PACKAGE_NAME: com.sentinel.project.util
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: HttpDownload
 * @DATE: 2021-1-7/18:04
 * @DAY_NAME_SHORT: 周四
 * @Description:
 **/
@Slf4j
public class HttpDownload {
    public static final int cache = 10 * 1024;
    public static final boolean isWindows;
    public static final String splash;
    public static final String root;

    static {
        if (System.getProperty("name") != null && System.getProperty("name").toLowerCase().contains("windows")) {
            isWindows = true;
            splash = "\\";
            root = "D:";
        } else {
            isWindows = false;
            splash = "/";
            root = "/search";
        }
    }

    /**
     * 根据url下载文件，文件名从response header头中获取
     *
     * @param url
     * @return
     */
    public static void getDownload(String url) {
        download(url, null);
    }

    /**
     * 根据url下载文件，文件名从response header头中获取
     *
     * @param url
     * @param params
     */
    public static void postDownload(String url, JSONObject params) {
        postDownloadFolder(url, params,null);
    }

    /**
     * 根据url下载文件,保存到filepath中
     *
     * @param url
     * @param params
     * @param filepath
     */
    private static void postDownloadFolder(String url, JSONObject params,String filepath) {
        CloseableHttpClient httpClient = getHttpClient();
        InputStream is = null;
        FileOutputStream fileOut = null;
        CloseableHttpResponse response = null;
        try {

            HttpPost httpPost = new HttpPost(url);
           httpPost.setHeader("Content-Type","application/json" );
            if (StringUtils.isNotBlank(params.toString())) {
                httpPost.setEntity(new StringEntity(params.toString(), Consts.UTF_8));
            }

            response = httpClient.execute(httpPost);
            Header[] allHeaders = response.getAllHeaders();
            for (Header header : allHeaders) {
                System.out.println(MessageFormat.format("header:{0}={1}", header.getName(), header.getValue()));
            }
            String fileName = response.getHeaders("Content-Disposition")[0].getValue().split("filename=")[1];
            System.out.println("文件名为" + fileName);

            HttpEntity entity = response.getEntity();
            is = entity.getContent();
            if (fileName == null) {
                fileName = getFilePath(response);
            }
            if (filepath != null) {
                fileName = filepath + splash + fileName;
            } else {
                fileName = splash + fileName;
            }
            File file = new File(fileName);
            file.getParentFile().mkdirs();
            fileOut = new FileOutputStream(file);
            /**
             * 根据实际运行效果 设置缓冲区大小
             */
            byte[] buffer = new byte[cache];
            int ch = 0;
            while ((ch = is.read(buffer)) != -1) {
                fileOut.write(buffer, 0, ch);
            }
            fileOut.flush();
            log.info("文件下载成功！");
        } catch (Exception e) {
            log.info("数据下载异常:{}", e.getMessage());
            e.printStackTrace();
        }finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (null != fileOut) {
                try {
                    fileOut.close();
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 根据url下载文件，保存到filepath中
     *
     * @param baseUrl
     * @param filepath
     * @return
     */
    public static void download(String baseUrl, String filepath) {
        InputStream is = null;
        FileOutputStream fileOut = null;
        try {
            CloseableHttpClient client = getHttpClient();
            HttpGet httpGet = new HttpGet(baseUrl);
            HttpResponse response = client.execute(httpGet);
            //获取消息头
            Header[] headers = response.getAllHeaders();
            for (Header header : headers) {
                System.out.println(MessageFormat.format("header:{0}={1}", header.getName(), header.getValue()));
            }
            String fileName = response.getHeaders("Content-Disposition")[0].getValue().split("filename=")[1];
            System.out.println("文件名为" + fileName);

            HttpEntity entity = response.getEntity();
            is = entity.getContent();
            if (fileName == null) {
                fileName = getFilePath(response);
            }
            if (filepath != null) {
                fileName = filepath + splash + fileName;
            } else {
                fileName = splash + fileName;
            }
            File file = new File(fileName);
            file.getParentFile().mkdirs();
            fileOut = new FileOutputStream(file);
            /**
             * 根据实际运行效果 设置缓冲区大小
             */
            byte[] buffer = new byte[cache];
            int ch = 0;
            while ((ch = is.read(buffer)) != -1) {
                fileOut.write(buffer, 0, ch);
            }
            fileOut.flush();
            log.info("文件下载成功！");
        } catch (Exception e) {
            log.info("数据下载异常:{}", e.getMessage());
            e.printStackTrace();
        } finally {
            if (is != null) {
                try {
                    is.close();
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            if (null != fileOut) {
                try {
                    fileOut.close();
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
    }

    /**
     * 获取response要下载的文件的默认路径
     *
     * @param response
     * @return
     */
    public static String getFilePath(HttpResponse response) {
        String filepath = root + splash;
        String filename = getFileName(response);

        if (filename != null) {
            filepath += filename;
        } else {
            filepath += getRandomFileName();
        }
        return filepath;
    }

    /**
     * 获取response header中Content-Disposition中的filename值
     *
     * @param response
     * @return
     */
    public static String getFileName(HttpResponse response) {
        Header contentHeader = response.getFirstHeader("Content-Disposition");
        String filename = null;
        if (contentHeader != null) {
            HeaderElement[] values = contentHeader.getElements();
            if (values.length == 1) {
                NameValuePair param = values[0].getParameterByName("filename");
                if (param != null) {
                    try {
                        //filename = new String(param.getValue().toString().getBytes(), "utf-8");
                        //filename=URLDecoder.decode(param.getValue(),"utf-8");
                        filename = param.getValue();
                    } catch (Exception e) {
                        e.printStackTrace();
                    }
                }
            }
        }
        return filename;
    }

    /**
     * 获取随机文件名
     *
     * @return
     */
    public static String getRandomFileName() {
        return String.valueOf(System.currentTimeMillis());
    }

    public static void outHeaders(HttpResponse response) {
        Header[] headers = response.getAllHeaders();
        for (int i = 0; i < headers.length; i++) {
            System.out.println(headers[i]);
        }
    }

    public static void main(String[] args) {
        String zip = "http://192.168.1.140:8090/api/download/";
        String text = "http://192.168.1.140:8090/api/download/txt";
        String docx = "http://192.168.1.140:8090/api/download/docx";
        String pdf = "http://192.168.1.140:8090/api/download/pdf";
        String xlsx = "http://192.168.1.140:8090/api/download/xlsx";
        String getDownload ="http://192.168.1.140:8082/api/data/query/streaming?datasourceId=2&query_database=product&query_table=table1&request_fileds=%7b%22flelds1%22:%20%22xxxx%22,%20%22field2%22:%22xxxx%22%7d&response_fields=field1,field2,field3,field4&data_size=100";
        String postDownload="http://192.168.1.140:8082/api/data/query/streaming1";
        //String filepath = "C:\\Users\\key\\Desktop\\ideaIU-2019.3.3";
        //HttpDownload.download(xlsx, null);
       //getDownload(getDownload);
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("datasourceId",1);
        jsonObject.put("query_database","product");
        jsonObject.put("query_table","table1");
        JSONObject jsonObject1 = new JSONObject();
        jsonObject1.put("flelds1","xxxxx");
        jsonObject1.put("field2","xxxxx");
        jsonObject.put("request_fileds",jsonObject1);
        jsonObject.put("response_fields","field1,field2,field3,field4");
        jsonObject.put("data_size",100);

        postDownloadFolder(postDownload,jsonObject,null);
    }
}
