package com.jz.dm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jz.common.constant.ResultMsg;
import com.jz.common.utils.Result;
import com.jz.dm.common.constant.Constants;
import com.jz.dm.common.enums.org.OrgStatusEnum;
import com.jz.dm.common.util.RandomUtil;
import com.jz.dm.mapper.ApiOrgMapper;
import com.jz.dm.models.domian.ApiOrg;
import com.jz.dm.models.req.organizationManage.OrganizationManageAddReq;
import com.jz.dm.models.req.organizationManage.OrganizationManageDetailQueryReq;
import com.jz.dm.models.req.organizationManage.OrganizationManageListQueryReq;
import com.jz.dm.service.OrganizationManageService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;

import static com.jz.dm.common.enums.org.OrgTypeEnum.fromOrgTypeEnumName;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.service.impl
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: OrganizationManageImpl
 * @DATE: 2020-12-23/16:50
 * @DAY_NAME_SHORT: 周三
 * @Description:
 **/
@Service("organizationManageService")
@Slf4j
public class OrganizationManageImpl implements OrganizationManageService {

    @Resource
    private ApiOrgMapper apiOrgMapper;

    /**
     * 组织列表信息查询
     *
     * @param req
     * @return
     */
    @Override
    public IPage<ApiOrg> listOrganization(OrganizationManageListQueryReq req) {
        IPage<ApiOrg> page = new Page<>(req.getPageNum(), req.getPageSize());
        QueryWrapper<ApiOrg> query = new QueryWrapper<>();

        if (StringUtils.isNotBlank(req.getOrgName())){
            query.like("org_name",req.getOrgName());
        }
        if (StringUtils.isNotBlank(req.getLinkman())){
            query.like("linkman",req.getLinkman());
        }
        if (StringUtils.isNotBlank(req.getOrgCode())){
            query.eq("org_code",req.getOrgCode());
        }
        query.eq("is_deleted", 0);
        query.orderByDesc("create_date");
        return apiOrgMapper.selectPage(page, query);
    }

    /**
     * 获取组织详情
     *
     * @param req
     * @return
     */
    @Override
    public Result getOrganizationDetail(OrganizationManageDetailQueryReq req) {
        QueryWrapper<ApiOrg> query = new QueryWrapper<>();
        query.eq("is_deleted", 0);
        query.eq("id", req.getId());
        /*query.ne("status",0);*/
        return Result.of_success(apiOrgMapper.selectOne(query));
    }

    /**
     * 添加组织/更新
     *
     * @param req
     * @return
     */
    @Override
    public Result add(OrganizationManageAddReq req) {
        ApiOrg apiOrg = new ApiOrg();
        BeanUtils.copyProperties(req, apiOrg);
        if (null != req.getId()){//更新
            ApiOrg org = apiOrgMapper.selectById(req.getId());
            if (null == org){
                return Result.of_error(ResultMsg.DATA_NOT_EXIST);
            }
             org.setUpdateDate(new Date());
            if ( apiOrgMapper.updateById(apiOrg) > 0){
                return Result.of_success(ResultMsg.UPDATE_SUCCESS);
            }
        }else {//添加
            Result result = addOrg(req, apiOrg);
            if (result != null) return result;
        }
        return Result.of_error(ResultMsg.FAILURE);
    }

    /**
     * 添加组织
     * @param req
     * @param apiOrg
     * @return
     */
    private Result addOrg(OrganizationManageAddReq req, ApiOrg apiOrg) {
        String coding = "";
        if (StringUtils.isNotBlank(req.getOrgName())) {
            ApiOrg orgNameInfo = getOrgNameInfo(req.getOrgName());
            if (null != orgNameInfo) {
                return Result.of_error("组织名称已存在!");
            }
        }
        if (StringUtils.isNotBlank(req.getOrgType())) {
            if (null == fromOrgTypeEnumName(req.getOrgType())){
                return Result.of_error("组织类型不存在!");
            }
        }
        if (StringUtils.isNotBlank(req.getOrgType()) //内部组织
                && Constants.AUTH_INT.equals(req.getOrgType())) {
            coding = generateCode(req.getOrgName(), Constants.AUTH_INT);
        } else {
            coding = generateCode(req.getOrgName(), Constants.AUTH_OUT);
        }
        if (StringUtils.isBlank(coding)) {
            return Result.of_error("生成组织编码异常!");
        }
        apiOrg.setOrgCode(coding);//组织编码
        if (apiOrgMapper.insert(apiOrg) > 0) {
            return Result.of_success(ResultMsg.INSERT_SUCCESS);
        }
        return null;
    }

    /**
     * 获取组织编码(去重)
     *
     * @param orgName 组织名称
     * @param type    生成类型
     * @return
     */
    private String generateCode(String orgName, String type) {
        String coding = "";
        coding = RandomUtil.generateOrgCoding(orgName, type);
        QueryWrapper<ApiOrg> query = new QueryWrapper<>();
        query.eq("org_code", coding);
        ApiOrg org = apiOrgMapper.selectOne(query);
        if (null != org) {
            coding = RandomUtil.generateOrgCoding(orgName, type);
        }
        return coding;
    }

    /**
     * 更新组织
     *
     * @param req
     * @return
     */
   /* @Override
    public Result update(OrganizationManageUpdateReq req) {
        ApiOrg apiOrg = apiOrgMapper.selectById(req.getId());
        if (null == apiOrg) {
            return Result.of_error("组织信息不存在!");
        }
        if (StringUtils.isNotBlank(req.getStatus())) {
            if (null == fromTypeName(req.getStatus())) {
                return Result.of_error("更新组织状态不存在!");
            }
        }
        //原状态为注销状态不可复原
        if (OrgStatusEnum.CANCEL.equals(apiOrg.getStatus())){
          return Result.of_error("注销状态不可修改");
        }
        ApiOrg apiOrgUpdate = new ApiOrg();
        BeanUtils.copyProperties(req, apiOrgUpdate);
        apiOrgUpdate.setUpdateDate(new Date());
        if (apiOrgMapper.updateById(apiOrgUpdate) > 0) {
            return Result.of_success(ResultMsg.UPDATE_SUCCESS);
        }
        return Result.of_success(ResultMsg.UPDATE_FAIL);
    }*/

    /**
     * 注销组织
     *
     * @param id
     * @return
     */
    @Override
    public Result logoutOrg(Long id) {
        ApiOrg apiOrg = apiOrgMapper.selectById(id);
        if (null == apiOrg) {
            return Result.of_error(ResultMsg.DATA_NOT_EXIST);
        }
        UpdateWrapper<ApiOrg> delete = new UpdateWrapper<>();
        delete.set("is_deleted", 1);
        delete.set("status",0);
        delete.eq("id", id);
        if (apiOrgMapper.update(null, delete) > 0) {
            return Result.of_success(ResultMsg.UPDATE_SUCCESS);
        }
        return Result.of_success(ResultMsg.UPDATE_FAIL);
    }

    /**
     * 获取认证组织信息
     *
     * @param apiOrgId
     * @return
     */
    @Override
    public ApiOrg getAuthOrganization(Long apiOrgId) {
        QueryWrapper<ApiOrg> query = new QueryWrapper<>();
        query.eq("id", apiOrgId);
        query.eq("status",1);
        query.eq("is_deleted", 0);
        return apiOrgMapper.selectOne(query);
    }

    /**
     * 根据名称获取组织信息
     *
     * @param orgName 组织名称
     * @return
     */
    private ApiOrg getOrgNameInfo(String orgName) {
        QueryWrapper<ApiOrg> query = new QueryWrapper<>();
        query.eq("org_name", orgName);
        query.eq("is_deleted", 0);
        query.eq("status", OrgStatusEnum.NORMAL);
        ApiOrg apiOrg = apiOrgMapper.selectOne(query);
        if (null != apiOrg) {
            return apiOrg;
        }
        return null;
    }
}
