package com.jz.dm.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import com.jz.common.exception.ResponseException;
import com.jz.common.utils.HttpsUtils;
import com.jz.common.utils.Md5;
import com.jz.common.utils.RedisUtils;
import com.jz.common.utils.Result;
import com.jz.dm.common.enums.GeneralStatusTypeEnum;
import com.jz.dm.common.enums.apiInterface.ApiInfoOutTypeEnum;
import com.jz.dm.common.enums.apiInterface.ApiStatusEnum;
import com.jz.dm.common.enums.produce.ProducerStatusTypeEnum;
import com.jz.dm.common.util.RandomUtil;
import com.jz.dm.mapper.*;
import com.jz.dm.models.domian.*;
import com.jz.dm.models.req.make.*;
import com.jz.dm.service.ApiInterfaceService;
import com.jz.dm.service.ProducerService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;

import static com.jz.dm.common.enums.apiInterface.ApiStatusEnum.fromApiStatusName;
import static com.jz.dm.common.enums.auth.AuthReqTypeEnum.fromAuthReqTypeEnum;

/**
 * @author ZC
 * @PACKAGE_NAME: com.jz.dm.service.impl
 * @PROJECT_NAME: jz-dm-parent
 * @NAME: ProducerServiceImpl
 * @DATE: 2020-12-23/16:57
 * @DAY_NAME_SHORT: 周三
 * @Description:
 **/
@Service("producerService")
@Slf4j
public class ProducerServiceImpl implements ProducerService {

    @Resource
    private ApiInterfaceMapper apiInterfaceMapper;
    @Resource
    private ApiSyncingDatasourceMapper apiSyncingDatasourceMapper;
    @Resource
    private ApiOpenApiEsFieldsMapper apiOpenApiEsFieldsMapper;
    @Resource
    private ApiOpenApiEsTagconfigMapper apiOpenApiEsTagconfigMapper;
    @Resource
    private ApiInterfaceCustomMapper apiInterfaceCustomMapper;
    @Resource
    private ApiInterfaceFileMapper apiInterfaceFileMapper;
    @Autowired
    private ApiInterfaceService apiInterfaceService;
    @Autowired
    private RedisUtils redisUtils;
    @Autowired
    private HttpsUtils httpsUtils;

    @Value("${dmp.openapi.timeout.max}")
    private int maxTimeout;
    @Value("${dmp.openapi.timeout.default}")
    private int defaultTimeout;
    //@Value("${dmp.openapi.env.open:false}")
    //private boolean envOpen = false;
    @Value("${dmp.ignoreRedis}")
    private boolean ignoreRedis;

    /**
     * dataBank签名token
     */
    @Value("${token.dataBank}")
    private String dataBankToken;

    /**
     * 获取文件列表
     *
     * @param projectId
     * @return
     */
    @Override
    public Result getFileCatalog(Long projectId) {
        return Result.of_success(apiInterfaceFileMapper.getFileFolderLevel(projectId));
    }


    /**
     * 创建文件夹
     *
     * @param projectId
     * @param parentId
     * @param currentUser
     * @return
     */
    @Override
    public Result createProjectFolder(Long projectId, Long parentId, String currentUser) {
        QueryWrapper<ApiInterfaceFile> query = new QueryWrapper<>();
        query.eq("id", parentId);
        query.eq("is_deleted", 0);
        ApiInterfaceFile apiInterfaceFile = apiInterfaceFileMapper.selectOne(query);
        if (null == apiInterfaceFile) {
            return Result.of_error("父级文件夹不存在!");
        }
        ApiInterfaceFile instanceFile = new ApiInterfaceFile();
        instanceFile.setProjectId(projectId);
        instanceFile.setFileSource("1");//文件来源:1 DMP 2 数据银行
        instanceFile.setParentId(parentId);
        instanceFile.setStatus(GeneralStatusTypeEnum.VALID.name());
        instanceFile.setCreateUser(currentUser);
        instanceFile.setRemark("DMP创建层级文件夹");
        if (apiInterfaceFileMapper.insert(instanceFile) > 0) {
            return Result.of_error(ResultMsg.INSERT_SUCCESS);
        }
        return Result.of_error(ResultMsg.INSERT_FAIL);
    }


    /**
     * DMP制作自定义Api
     *
     * @param req
     * @return
     */
    @Override
    public Result addCustomApi(ApiInterfaceReq req) {
        return saveInterfaceAPi(req);
    }

    /**
     * 数据银行制作API/数据包/自定义
     *
     * @param req
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRES_NEW)
    public Result addDataBankApiInfo(MakeDataBankApiReq req) {
     /*   QueryWrapper<ApiInterfaceFile> query = new QueryWrapper<>();
        query.eq("file_source", "2");
        query.eq("is_deleted", 0);
        List<ApiInterfaceFile> fileSource = apiInterfaceFileMapper.selectList(query);
        if (fileSource.size() == 0 || fileSource.size() >= 2) {
            return Result.of_error("文件夹信息异常!");
        }*/
        if (StringUtils.isNotBlank(req.getOutputType())) {
            if (!req.getOutputType().contains(ApiInfoOutTypeEnum.JSON.name()) ||
                    !req.getOutputType().contains(ApiInfoOutTypeEnum.FLOW.name())) {
                return Result.of_error("输出类型不存在!");
            }
        }
        if (StringUtils.isNotBlank(req.getReqType())) {
            if (null == fromAuthReqTypeEnum(req.getReqType())) {
                return Result.of_error("限流类型不存在!");
            }
        }
        String signStr = dataBankToken + req.getJoinType();
        String signResult = Md5.encrypt(signStr, "");
        if (!signResult.equals(req.getSign())) {
            return Result.of_error("签名错误!");
        }
        String apiKey = getApiKey();
        switch (req.getJoinType()) {
            case "10006"://数据银行三方上传
                saveDataBanker(req, apiKey, "3");
                break;
            case "10007"://数据银行数据包上传
                if(StringUtils.isNotBlank(req.getFileLocation()))return Result.of_error("文件地址不存在!");
                saveDataBanker(req, apiKey, "2");
                break;
            case "10008"://数据银行制作大数据表
                saveDataBanker(req, apiKey, "1");
                break;
            default:
                return Result.of_error("接入类型不存在!");
        }
        return Result.of_success(ResultMsg.INSERT_SUCCESS, apiKey);
    }

    /**
     * 保存数据银行api信息并缓存
     *
     * @param req     请求参数
     * @param apiKey  apiKey
     * @param apiType api类型
     */
    private void saveDataBanker(MakeDataBankApiReq req, String apiKey, String apiType) {
        ApiInterface apiInterface = saveApiInterFace(req, apiKey, apiType);
        saveApiInterFaceCustom(req, apiKey, apiInterface.getId());
        JSONObject object = new JSONObject();
        object.put("targetUrl", req.getTargetUrl());
        object.put("outputType", req.getOutputType());
        object.put("reqMethod",req.getReqMethod());
        saveObjOnRedis(apiInterface.getApiKey(), object);
    }

    /**
     * 保存api基本信息
     *
     * @param req
     * @param apiKey
     * @param apiType
     * @return
     */
    private ApiInterface saveApiInterFace(MakeDataBankApiReq req,
                                          String apiKey, String apiType) {
        ApiInterface anInterface = new ApiInterface();
        anInterface.setApiType(apiType);//数据银行制作大数据表
        anInterface.setStatus(ProducerStatusTypeEnum.ISSUE.name());//发布
        anInterface.setApiKey(apiKey);//apiKey
        BeanUtils.copyProperties(req, anInterface);
        if (apiInterfaceMapper.insert(anInterface) == 0) {
            throw ResponseException.of(ResultCode.FAILURE, "保存api基本信息异常!");
        }
        return anInterface;
    }

    /**
     * 保存APi扩展信息
     *
     * @param req
     * @param apiKey
     * @param interFaceId
     * @return
     */
    private ApiInterfaceCustom saveApiInterFaceCustom(MakeDataBankApiReq req, String apiKey,
                                                      Long interFaceId) {
        ApiInterfaceCustom interfaceCustom = new ApiInterfaceCustom();
        interfaceCustom.setApiKey(apiKey);
        interfaceCustom.setApiInterfaceId(interFaceId);
        BeanUtils.copyProperties(req, interfaceCustom);
        if (apiInterfaceCustomMapper.insert(interfaceCustom) == 0) {
            throw ResponseException.of(ResultCode.FAILURE, "保存api扩展信息异常!");
        }
        return interfaceCustom;
    }

    /**
     * Api制作(实时接入)
     *
     * @param req
     * @return
     */
    @Override
    public Result addRealCustomApi(MakeRealCustomApiReq req) {

        return null;
    }

    /**
     * DMP大数据查询/标签查询
     *
     * @param req
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRES_NEW)
    public Result addBigDataMakeApi(MakeBigDataApiReq req) {
        ApiInterface apiInterface = apiInterfaceService.getApiInfo(req.getApiKey());
        if (null == apiInterface) {
            return Result.of_error("API基本信息为空!");
        }
        QueryWrapper<ApiOpenApiEsFields> queryOpenApi = new QueryWrapper<>();
        queryOpenApi.eq("es_database", req.getEsDataBase());
        queryOpenApi.eq("es_table", req.getEsTable());
        queryOpenApi.eq("is_deleted", 0);
        List<ApiOpenApiEsFields> listOpenApiEsFields = apiOpenApiEsFieldsMapper.selectList(queryOpenApi);
        //如果存在先根据库，表删除，重新添加
        if (CollectionUtils.isNotEmpty(listOpenApiEsFields)) {
            Map paMap = new HashMap<>();
            paMap.put("es_database", req.getEsDataBase());
            paMap.put("es_table", req.getEsTable());
            apiOpenApiEsFieldsMapper.deleteByMap(paMap);
        }
        ArrayList<ApiOpenApiEsFields> listApiEsFields = new ArrayList<>();
        //保存字段表中的字段信息
        JSONArray json = JSONArray.parseArray(req.getTableFields());
        for (int i = 0; i < json.size(); i++) {
            JSONObject jsonObject = (JSONObject) json.get(i);
            ApiOpenApiEsFields fields = new ApiOpenApiEsFields();
            fields.setEsDatabase(req.getEsDataBase());
            fields.setEsTable(req.getEsTable());
            fields.setFieldName(jsonObject.get("name").toString());
            fields.setFieldType(jsonObject.get("type").toString());
            fields.setFieldDesc(jsonObject.get("desc").toString());
            fields.setCreateUser(req.getCreateUser());
            listApiEsFields.add(fields);
        }
        //保存字段表中的字段信息
        if (CollectionUtils.isNotEmpty(listApiEsFields)) {
            apiOpenApiEsFieldsMapper.insetBatch(listApiEsFields);
        }
       /* //调用dmp接口获取数据库连接信息
        ApiSyncingDatasource dataSource = apiSyncingDatasourceMapper.selectById(req.getEsDataSource());
        if (null != dataSource) {
            //esjdbc 连接地址 用于接口中调用获取es数据
            redisUtils.set(TagConstants.OPEN_API_ESTAG_JDBC_INFO_NAMESPACE + apiInterface.getApiKey(), dataSource.getJdbcUrl());
        }*/
        int result = 0;
        ApiInterfaceCustom interfaceCustom = new ApiInterfaceCustom();
        if (null != req.getId() && !"".equals(req.getId())) {//更新
            BeanUtils.copyProperties(req, interfaceCustom);
            interfaceCustom.setUpdateDate(new Date());
            interfaceCustom.setUpdateUser(req.getCreateUser());
            result = apiInterfaceCustomMapper.updateById(interfaceCustom);
        } else {  //保存
            BeanUtils.copyProperties(req, interfaceCustom);
            interfaceCustom.setCreateUser(req.getCreateUser());
            interfaceCustom.setApiInterfaceId(apiInterface.getId());
            result = apiInterfaceCustomMapper.insert(interfaceCustom);
        }
        if (result <= 0) {
            return Result.of_error(ResultMsg.FAILURE);
        }
        return Result.of_success(ResultMsg.SUCCESS, req.getId());
    }

    /**
     * DMP保存api基本信息/自定义API
     *
     * @param req
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRED)
    public Result saveInterfaceAPi(ApiInterfaceReq req) {
        if (StringUtils.isNotBlank(req.getReqType())) {
            if (null == fromAuthReqTypeEnum(req.getReqType())) {
                return Result.of_error("限流类型不存在!");
            }
        }
        //生成ApiKey
        String apiKey = getApiKey();
        ApiInterface apiInterface = new ApiInterface();
      /*  if (null == req.getFileId()) {//创建下级文件夹
            Long fileId = checkFileExist(req.getProjectId(), req.getParentId(), req.getCreateUser());
            req.setFileId(fileId);
        }*/
        BeanUtils.copyProperties(req, apiInterface);
        apiInterface.setApiKey(apiKey);
        apiInterface.setApiProtocl(req.getTransMode());//传输方式 https http
        apiInterface.setStatus(ApiStatusEnum.ISSUE.name());//发布
        if ("10004".equals(req.getJoinType())) {//dmp自定义
            apiInterface.setApiType("7");
        } else if ("10002".equals(req.getJoinType())) {//大数据表查询
            apiInterface.setApiType("6");
        }
        Long timeout = Long.parseLong(req.getTimeout());
        if (timeout == null || timeout == 0) {
            apiInterface.setTimeout(String.valueOf(defaultTimeout));
        } else if (timeout < 0) {
            return Result.of_error("接口超时时间最小0ms");
        } else if (timeout > maxTimeout) {
            return Result.of_success("接口超时时间最大5000ms");
        }
        if (apiInterfaceMapper.insert(apiInterface) == 0) {
            throw ResponseException.of_error("保存Api信息失败!");
        }
        JSONObject object = new JSONObject();
        object.put("targetUrl", req.getTargetUrl());
        object.put("outputType", ApiInfoOutTypeEnum.JSON.name());
        saveObjOnRedis(apiInterface.getApiKey(), object);
        return Result.of_success(ResultMsg.INSERT_SUCCESS, apiKey);
    }

    /**
     * 缓存数据
     *
     * @param apiKey
     * @param params
     */
    private void saveObjOnRedis(String apiKey, JSONObject params) {
        if (StringUtils.isBlank(apiKey) || null == params) {
            log.info("--------------缓存数据为空");
            return;
        }
        try {
            String paramKey = redisUtils.get(apiKey);
            if (null != paramKey) {
                redisUtils.del(apiKey);
            }
            redisUtils.set(apiKey, params.toString());
        } catch (Exception ex) {
            log.error("缓存api制作数据异常:{}", ex.getMessage());
            ex.printStackTrace();
        }
    }

    /**
     * 校验文件夹信息
     *
     * @param projectId
     * @param parentId
     * @param userName
     * @return
     */
    private Long checkFileExist(Long projectId, Long parentId, String userName) {
        if (null == parentId) {
            throw ResponseException.of_error("父文件id不能为空");
        }
        if (null == projectId) {
            throw ResponseException.of_error("项目id不能为空");
        }
        QueryWrapper<ApiInterfaceFile> query = new QueryWrapper<>();
        query.eq("project_id", projectId);
        query.eq("parent_id", parentId);
        ApiInterfaceFile file = apiInterfaceFileMapper.selectOne(query);
        if (null == file && 0 != parentId) {
            throw ResponseException.of(ResultCode.FAILURE, "父类文件夹不存在!");
        }
        if (null == file) {
            //查询父类是否存在
            ApiInterfaceFile apiInterfaceFile =
                    apiInterfaceFileMapper.selectOne(new QueryWrapper<ApiInterfaceFile>().eq("parent_id", parentId));
            if (null == apiInterfaceFile && 0 == parentId) {
                file = new ApiInterfaceFile();
                file.setProjectId(projectId);
                file.setFileSource("1");//dmp
                file.setParentId(0L);
                file.setStatus(GeneralStatusTypeEnum.VALID.name());
                file.setCreateUser(userName);
                file.setRemark("创建文件夹");
                if (apiInterfaceFileMapper.insert(file) == 0) {
                    throw ResponseException.of_error("创建文件夹失败!");
                }
            } else {
                throw ResponseException.of(ResultCode.FAILURE, "父类文件信息不存在!");
            }
        }
        return file.getId();
    }

    /**
     * 保存修改的api信息
     *
     * @param req
     * @return
     */
    @Override
    public Result saveUpdateAPiInfo(ApiInterfaceReq req) {
        ApiInterface apiInterface = apiInterfaceMapper.selectById(req.getId());
        if (null == apiInterface) {
            return Result.of_error(ResultMsg.DATA_NOT_FOUND);
        }
        if (StringUtils.isBlank(req.getSignType()) || "0".equals(req.getSignType())) {
            return Result.of_error("加密类型错误!");
        }
        if (StringUtils.isNotBlank(req.getReqType())) {
            if (null == fromAuthReqTypeEnum(req.getReqType())) {
                return Result.of_error("限流类型不存在!");
            }
        }
        if (StringUtils.isNotBlank(req.getStatus())) {
            if (null == fromApiStatusName(req.getStatus())) {
                return Result.of_error("更新状态不存在!");
            }
        }
        if (StringUtils.isNotBlank(req.getStatus())) {
            if (!canChange(apiInterface.getStatus(), req.getStatus())) {
                String errorMsg = String.format("api当前状态为%s不可变更为%s",
                        ApiStatusEnum.valueOf(apiInterface.getStatus()).getText(),
                        ApiStatusEnum.valueOf(req.getStatus()).getText());
                return Result.of_error(errorMsg);
            }
        }
        if (null != req.getReqFrequency()) {
            if (req.getReqFrequency() <= 0) {
                return Result.of_error("限流次数不能小于或者等于零");
            }
        }
        apiInterface.setApiType(req.getApiType());
        apiInterface.setApiDesc(req.getApiDesc());
        apiInterface.setReqType(req.getReqType());
        apiInterface.setReqFrequency(req.getReqFrequency());
        apiInterface.setVersion(RandomUtil.generateVersion(apiInterface.getVersion()));//版本自动累加
        apiInterface.setSignType(req.getSignType());
        apiInterface.setApiFunction(req.getApiFunction());
        apiInterface.setStatus(req.getStatus());
        apiInterface.setApiProtocl(req.getTransMode());//传输方式 https http
        apiInterface.setUpdateDate(new Date());
        apiInterface.setUpdateUser(req.getCreateUser());
        if (StringUtils.isNotBlank(req.getTargetUrl())) {
            apiInterface.setTargetUrl(req.getTargetUrl());
        }
        Long timeout = Long.parseLong(req.getTimeout());
        if (timeout == null || timeout == 0) {
            apiInterface.setTimeout(String.valueOf(defaultTimeout));
        } else if (timeout < 0) {
            return Result.of_error("接口超时时间最小0ms");
        } else if (timeout > maxTimeout) {
            return Result.of_success("接口超时时间最大5000ms");
        }
        apiInterface.setTimeout(req.getTimeout());
        if (apiInterfaceMapper.updateById(apiInterface) > 0) {
            return Result.of_success(ResultMsg.UPDATE_SUCCESS);
        }
        JSONObject object = new JSONObject();
        object.put("targetUrl", req.getTargetUrl());
        object.put("outputType", ApiInfoOutTypeEnum.JSON.name());
        saveObjOnRedis(apiInterface.getApiKey(), object);
        return Result.of_success(ResultMsg.UPDATE_FAIL);
    }

    /**
     * 判断状态是否改变
     *
     * @param currentStatus
     * @param toStatus
     * @return
     */
    private boolean canChange(String currentStatus, String toStatus) {
        if (StringUtils.equals(currentStatus, toStatus)) {
            log.info("api的状态一直，crrentStatus:{},toStatus:{}", currentStatus, toStatus);
            return true;
        }
        //已经失效
        if (StringUtils.equals(currentStatus, ApiStatusEnum.EXPIRY.name())) {
            log.info("api的状态是：{}，不能修改为：{}", currentStatus, toStatus);
            return false;
        }
        //toStatus 草稿  其它状态不能变更为草稿
        if (StringUtils.equals(toStatus, ApiStatusEnum.DRAFT.name())) {
            log.info("api的状态是：{}[{}]，不能修改为：{}[{}]", currentStatus,
                    ApiStatusEnum.DRAFT.getText(), toStatus, ApiStatusEnum.DRAFT.getText());
            return false;
        }
        return true;
    }


    /**
     * 获取数据源配置
     *
     * @param req
     * @return
     */
    @Override
    public Result getSourceConfig(SourceConfigReq req) {
        if (StringUtils.isBlank(req.getApiKey())) {
            return Result.of_success("Api不能为空");
        }
        if (StringUtils.isNotBlank(req.getReleaseId())) {
            ApiInterface anInterface = apiInterfaceMapper.selectOne(new QueryWrapper<ApiInterface>().eq("api_key", req.getApiKey()));
            if (null != anInterface) {
                return Result.of_error("存在重复的Apikey");
            }
        } else {
            QueryWrapper<ApiInterface> query = new QueryWrapper<>();
            query.eq("api_key", req.getApiKey());
            query.eq("is_deleted", 0);
            ApiInterface apiInterface = apiInterfaceMapper.selectOne(query);
            if (null != apiInterface) {
                return Result.of_error("存在重复的Apikey");
            }
        }
        return Result.of_success(ResultMsg.SUCCESS);
    }

    /**
     * 获取数据源库配置
     *
     * @param id
     * @return
     */
    @Override
    public Result getSourceWarehouseList(Long id) {
        ApiSyncingDatasource datasource = apiSyncingDatasourceMapper.selectById(id);
        if (null == datasource) {
            return Result.of_error("数据源不存在!");
        }
        JSONArray result = new JSONArray();
        log.info("查询es标签类下的索引地址信息:" + datasource.getJdbcUrl() + "/es/get/indicess");
        String resp = httpsUtils.doGet(datasource.getJdbcUrl() + "/es/get/indicess", new HashMap<>());
        if (resp != null) {
            log.info("返回索引信息集合:" + resp);
            JSONArray json = JSONArray.parseArray(resp);
            for (int i = 0; i < json.size(); i++) {
                String database = json.get(i).toString();
                //除去已点开头的索引返回前端
                if (!database.startsWith(".")) {
                    result.add(database);
                }
            }
            log.info("过滤后索引信息集合:" + result.toJSONString());
        }

        return Result.of_success(result);
    }

    /**
     * 获取某个索引下的type
     *
     * @param indices
     * @param id
     * @return
     */
    @Override
    public Result getIndicesTypes(String indices, Long id) {
        ApiSyncingDatasource datasource = apiSyncingDatasourceMapper.selectById(id);
        if (null == datasource) {
            return Result.of_error("数据源不存在!");
        }
        log.info("查询es标签类索引下的type的地址信息:" + datasource.getJdbcUrl() + "/es/get/indices/types");
        JSONObject param = new JSONObject();
        param.put("indices", indices);
        log.info("参数集合：" + param.toString());
        String resp = httpsUtils.submitPost(datasource.getJdbcUrl() + "/es/get/indices/types", param.toString());
        log.info("索引下type的信息集合:" + resp);
        return Result.of_success(resp);
    }

    /**
     * 获取某个索引 type的fields
     *
     * @param indices
     * @param type
     * @param id
     * @return
     */
    @Override
    public Result getIndicesTypesFields(String indices, String type, Long id) {
        ApiSyncingDatasource datasource = apiSyncingDatasourceMapper.selectById(id);
        if (null == datasource) {
            return Result.of_error("数据源不存在!");
        }
        log.info("查询es标签类洗typeFields地址信息:" + datasource.getJdbcUrl() + "/es/get/type/fields");
        HashMap<String, String> herders = new HashMap<>();
        herders.put("Content-Encoding", "UTF-8");
        herders.put("Content-Type", "application/json");
        JSONObject param = new JSONObject();
        param.put("indices", indices);
        param.put("type", type);
        String resp = null;
        try {
            resp = httpsUtils.submitPost(datasource.getJdbcUrl() + "/es/get/type/fields", param, herders);
            log.info("索引下type的fields信息集合:" + resp);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return Result.of_success(resp);
    }


    /**
     * 获取不重复的apiKey
     *
     * @return
     */
    private String getApiKey() {
        String random = RandomUtil.getStringRandom(16);
        QueryWrapper<ApiInterface> query = new QueryWrapper<>();
        query.eq("api_key", random);
        query.eq("is_deleted", 0);
        ApiInterface apiInterface = apiInterfaceMapper.selectOne(query);
        if (null != apiInterface) {
            random = RandomUtil.getStringRandom(16);
        }
        return random;
    }


    @Override
    public Result saveObjOnRedis() {
        MakeDataBankApiReq bankApiReq = new MakeDataBankApiReq();
       /* bankApiReq.setTransMode("HTTPS");
        bankApiReq.setSignType("MD5");
        bankApiReq.setJoinType("10004");
        bankApiReq.setOutputType("JSON");
        bankApiReq.setPage(false);
        bankApiReq.setReqType("DAY");
        bankApiReq.setTargetUrl("www.baidu.com");
        bankApiReq.setFileId(1L);
        bankApiReq.setSign("F2A8E3CFE528D6AE5C5B075046653F3E");
        bankApiReq.setReqFrequency(0L);
        bankApiReq.setApiDesc("4444");
        bankApiReq.setTimeout("5000");
        net.sf.json.JSONObject jsonObject = net.sf.json.JSONObject.fromObject(bankApiReq);
        redisUtils.set("apiKeyTest", jsonObject, 300);*/
        JSONObject object = new JSONObject();
        object.put("targetUrl", "www.baidu.common");
        object.put("outputType", ApiInfoOutTypeEnum.JSON.name());
        saveObjOnRedis("apiKeyTest002", object);
        return Result.ok();
    }

    @Override
    public Result getObjOnRedis() {
        String apiKeyTest002 = redisUtils.get("apiKeyTest002");
        // JSONObject jsonObject = JSONObject.parseObject(apiKeyTest);
        JSONObject jsonObject = JSONObject.parseObject(apiKeyTest002);
        System.out.println(jsonObject);
        return Result.ok();
    }
}
