package com.jz.dm.mall.moduls.mapper;

import com.jz.common.base.BaseMapper;
import com.jz.common.entity.Department;
import com.jz.common.utils.Result;
import com.jz.dm.mall.moduls.controller.company.bean.CompanyAddReq;
import com.jz.dm.mall.moduls.controller.company.dto.CompanyInfoDto;
import com.jz.dm.mall.moduls.controller.customer.bean.dto.PurchaserUserCenterDto;
import com.jz.dm.mall.moduls.entity.City;
import com.jz.dm.mall.moduls.entity.Province;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.ResultType;
import org.apache.ibatis.annotations.Select;

import java.util.List;

/**
 * 企业(TDepartment)表数据库访问层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
public interface DepartmentDao extends BaseMapper<Department> {

    /**
     * 查询企业信息
     * @param req
     * @return
     */
    Department selectDepartmentData(@Param("req") CompanyAddReq req);

    /**
     * 查询企业状态
     * @param departmentId
     * @return
     */
    @Select("select audit_status AS auditStatus from t_department where department_id =#{departmentId} and del_flag ='N'")
    @ResultType(String.class)
    String selectCompanyStatus(Long departmentId);

    /**
     * 根据企业ID查询企业信息
     * @param departmentId
     * @return
     */
    CompanyInfoDto  selectCompanyDetail(@Param("departmentId") Long departmentId);

    /**
     * 保存企业认证信息
     * @param dep
     * @return
     */
    int insertDepart(@Param("dep") Department dep);

    /**
     * 获取省份
     * @return
     */
    List<Province> selectAll();

    /**
     * 获取城市
     * @param provinceCode
     * @return
     */
    List<City> selectByCity(@Param(value = "provinceCode") String provinceCode);

    List<String> getAreaList(@Param("provinceCode") String provinceCode, @Param("cityCode")String cityCode);

    List<String> getCityList(@Param(value = "provinceCode") String provinceCode);

    PurchaserUserCenterDto selectByBasic(@Param("customerId") Long customerId);
}