package com.jz.dm.mall.moduls.service.impl;

import com.jz.common.bean.SysUserDto;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.controller.goods.bean.dto.DataDetailsDto;
import com.jz.dm.mall.moduls.controller.goods.bean.dto.DataGoodsApiDto;

import com.jz.dm.mall.moduls.mapper.DataGoodsApiDao;
import com.jz.dm.mall.moduls.service.DataGoodsApiService;


import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;


import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.TimeUnit;

/**
 * api商品(TDataGoodsApi)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:31
 */
@Service("dataGoodsApiService")
public class DataGoodsApiServiceImpl implements DataGoodsApiService {
    @Autowired
    private DataGoodsApiDao tDataGoodsApiDao;



    /**
     * 根据主键查询商品api详情
     *
     * @param id
     * @return
     */
    @Override
    public Result selectById(Long id) {

        List<DataGoodsApiDto> dataGoodsApiDto = tDataGoodsApiDao.selectById(id);
        if (dataGoodsApiDto.size() == 0) {
            return Result.error(StatusCode.ERROR, "查询异常！");
        }
        List<DataGoodsApiDto> list1 = new ArrayList<>();
        List<DataGoodsApiDto> list2 = new ArrayList<>();
        List<DataGoodsApiDto> list3 = new ArrayList<>();
        Map<String, Object> map = new HashMap<>();

        for (DataGoodsApiDto goodsApiDto : dataGoodsApiDto) {
            if (goodsApiDto.getParamsDiffNum()!= null && goodsApiDto.getParamsDiffNum().equals("01")) {
                list1.add(goodsApiDto);
            }
            if (goodsApiDto.getParamsDiffNum()!= null && goodsApiDto.getParamsDiffNum().equals("02")) {
                list2.add(goodsApiDto);
            }
            if (goodsApiDto.getParamsDiffNum()!= null && goodsApiDto.getParamsDiffNum().equals("03")) {
                list3.add(goodsApiDto);
            }
            if (!StringUtils.isEmpty(goodsApiDto.getRequestExample())) {
                map.put("requestExample", goodsApiDto.getRequestExample()); // 请求示例
            }
            if (!StringUtils.isEmpty(goodsApiDto.getReturnDataExample())) {
                map.put("returnDataExample", goodsApiDto.getReturnDataExample()); // 响应示例
            }
        }
        // 商品详情
        DataGoodsApiDto goods = dataGoodsApiDto.get(0);
        DataDetailsDto data = new DataDetailsDto();
        DecimalFormat df = new DecimalFormat("#0.00");
        String str = df.format(goods.getDataPrice());
        BigDecimal bd = new BigDecimal(str).setScale(2, RoundingMode.HALF_UP);
        data.setDataPrice(bd);
        BeanUtils.copyProperties(goods, data);
        map.put("dataInfo", data);

        // 商品参数
        map.put("pubParam", list1); // 公共参数
        map.put("reqParam", list2); // 请求参数
        map.put("resParam", list3); // 响应参数

        Result result = new Result();
        result.setData(map);
        return Result.of_success(ResultMsg.SUCCESS, result);
    }


}