package com.jz.dm.mall.moduls.service.impl;

import com.jz.common.utils.FtpUtil;
import com.jz.common.utils.RandomUtil;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.dm.mall.moduls.service.PictureService;
import org.apache.commons.net.ftp.FTPClient;
import org.apache.commons.net.ftp.FTPReply;
import org.apache.tomcat.util.http.fileupload.IOUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.io.InputStream;

/**
 * @ClassName:
 * @Author: Carl
 * @Date: 2021/1/12
 * @Version:
 */
@Service("pictureService")
public class PictureServiceImpl implements PictureService {
    @Value("${ftp.url}")
    private String ftpUrl;

    @Value("${ftp.port}")
    private Integer port;

    @Value("${ftp.username}")
    private String username;

    @Value("${ftp.password}")
    private String password;


    /**
     * 图片上传
     *
     * @param file
     * @return
     */
    @Override
    public Result uploadPicture(MultipartFile file, String params) {
        Result result = new Result();
        if (file.getSize() > 10240000) {
            return Result.of_error("图片格式太大，不能超过10MB!");
        }
        // 获取图片名称
        String originalFilename = file.getOriginalFilename();
        // 获取图片扩展名
        String extensionName = originalFilename.substring(originalFilename.lastIndexOf("."));
        // 重新命名图片
        String picture = RandomUtil.getStringRandom(16) + extensionName;
        // 上传图片
        try {
            String filePath = "";
            if (params.equals("logo")) {
                filePath = "/picture/logo";
            }else if (params.equals("businessLicense")) {
                filePath = "/picture/businessLicense";
            }
            boolean flag = FtpUtil.uploadFile(ftpUrl, port, username, password, "/", filePath, picture, file.getInputStream());
            if (flag) {
                String url = "/manage/downloadPicture?url=" + filePath + "/" + picture;
                result.setData(url);
                result.setMsg("图片上传成功!");
            }else {
                result.setMsg("图片上传失败!");
                result.setCode(StatusCode.ERROR);
            }
        } catch (IOException e) {
            e.printStackTrace();
            result.setMsg("图片上传失败!");
            result.setCode(StatusCode.ERROR);
        }
        return result;
    }

    /**
     * 图片下载
     *
     * @param url
     * @return
     */
    @Override
    public Result downloadPicture(String url, HttpServletResponse response) {
        Result result = new Result();
        FTPClient ftp = new FTPClient();
        String catalog = url.substring(url.lastIndexOf("=")+ 1);
        String remotePath = catalog.substring(0, catalog.lastIndexOf("/") + 1);
        String furl = url.substring(url.lastIndexOf("/") +1);
        String suffix = catalog.substring(catalog.lastIndexOf("."));
        try {
            int reply;
            ftp.connect(ftpUrl, port);
            // 登录
            ftp.login(username, password);
            reply = ftp.getReplyCode();
            if (!FTPReply.isPositiveCompletion(reply)) {
                ftp.disconnect();
            }
            ftp.enterLocalPassiveMode();
            // 到FTP服务器目录
            ftp.changeWorkingDirectory(remotePath);
            InputStream in = ftp.retrieveFileStream(furl);
            ServletOutputStream outputStream = response.getOutputStream();
            int len = 0;
            byte[] buffer = new byte[1024];
            while ((len = in.read(buffer)) != -1) {
                outputStream.write(buffer, 0, len);
            }
//            byte[] bytes = sos.toByteArray();
            response.setHeader("Content-Disposition", "attachment;filename="+suffix);
            IOUtils.copy(in, outputStream);
            in.close();
            outputStream.close();
            ftp.logout();
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            if (ftp.isConnected()) {
                try {
                    ftp.disconnect();
                } catch (Exception ioe) {
                }
            }
        }
        return result;
    }
}
