package com.jz.manage.moduls.controller.customer;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.jz.common.constant.ResultMsg;
import com.jz.common.utils.Result;
import com.jz.common.utils.StatusCode;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.customer.bean.dto.CompanyDetailsDto;
import com.jz.manage.moduls.controller.customer.bean.dto.EnterpriseAuditDto;
import com.jz.manage.moduls.controller.customer.bean.request.DepartmentAuditReq;
import com.jz.manage.moduls.controller.customer.bean.request.EnterpriseAuditRequest;
import com.jz.manage.moduls.controller.customer.bean.request.SaveCustomerRequest;
import com.jz.manage.moduls.service.DepartmentService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 企业(Department)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
@RestController
@RequestMapping("department")
@Api(tags = "企业信息管理--controller")
public class DepartmentController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private DepartmentService departmentService;

    /**
     * 条件分页查询企业审核信息
     * @param auditRequest
     * @param req
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/findList")
    @ApiOperation(value = "条件分页查询企业审核信息")
    public Result<IPage<EnterpriseAuditDto>> findList(@RequestBody EnterpriseAuditRequest auditRequest, HttpServletRequest req) throws Exception {
        return departmentService.findList(auditRequest, req);
    }

    /**
     * 主键获取企业审核信息
     * @param id
     * @param req
     * @return
     */
    @GetMapping(value = "/getDepartment/{id}")
    @ApiOperation(value = "主键查询用户企业详情信息")
    public Result selectById(@PathVariable(value = "id") Long id, HttpServletRequest req) throws Exception{
        if (id != null) {
            return departmentService.selectById(id);
        }
        return Result.error("查询企业详情失败");
    }

    /**
     * 企业审核接口
     * @param
     * @return
     */
    @PostMapping(value = "/audit")
    @ApiOperation(value = "企业审核")
    public Result audit(@RequestBody DepartmentAuditReq req) throws Exception{
        if (!StringUtils.isEmpty(req)) {
            return departmentService.audit(req);
        }
        return Result.error("企业审核失败");
    }

    /**
     * 添加用户
     * @param saveCustomerRequest
     * @param req
     * @return
     * @throws Exception
     */
    @PostMapping(value = "/add")
    @ApiOperation(value = "添加用户")
    public Result add(@RequestBody SaveCustomerRequest saveCustomerRequest, HttpServletRequest req) throws Exception {
        if (saveCustomerRequest != null) {
            return departmentService.add(saveCustomerRequest, req);
        }
        return Result.error("添加用户失败！");
    }
}