package com.jz.manage.moduls.controller.finance;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.constant.ResultMsg;
import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.finance.platForm.*;
import com.jz.manage.moduls.service.FinanceCustomerBalanceService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 企业客户充值记录(TFinanceCustomerBalance)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:39
 */
@RestController
@RequestMapping("financeCustomerBalance")
@Api(tags = "平台--利润中心")
public class FinanceCustomerBalanceController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private FinanceCustomerBalanceService financeCustomerBalanceService;

    /**
     * 充值管理--分页列表
     *
     * @return
     * @author Bellamy
     * @since 2020-12-03
     */
    @PostMapping(value = "/cashOutList")
    @ApiOperation(value = "充值管理--分页列表", notes = "分页列表")
    public Result<IPage<BalanceListDto>> getFinanceCashOutList(@RequestBody BalanceListRequest balanceListRequest, HttpServletRequest httpRequest) throws Exception {
        IPage<BalanceListDto> pageInfo = financeCustomerBalanceService.findListBalance(balanceListRequest, httpRequest);
        if (pageInfo.getSize() == 0) {
            return Result.of_error("搜索失败！");
        }
        return Result.of_success(ResultMsg.SUCCESS, pageInfo);
    }

    /**
     * 充值管理--充值详情
     *
     * @return
     * @author Bellamy
     * @since 2020-12-06
     */
    @GetMapping(value = "/balanceInfoById")
    @ApiOperation(value = "充值管理--充值详情", notes = "充值详情")
    public Result<BalanceInfoDto> getFinanceBalanceInfoById(@RequestParam(value = "customerBalanceId") String customerBalanceId, HttpServletRequest httpRequest) throws Exception {
        Result<BalanceInfoDto> result = new Result<>();
        if (StringUtils.isEmpty(customerBalanceId)) {
            result.setMsg("参数为空！");
            result.setSuccess(false);
            return result;
        }
        BalanceInfoDto dto = financeCustomerBalanceService.queryBalanceByid(customerBalanceId);
        result.setData(dto);
        return result;
    }

    /**
     * 充值管理--充值审核
     *
     * @return
     * @author Bellamy
     * @since 2020-12-08
     */
    @PostMapping(value = "/balanceInfoAudit")
    @ApiOperation(value = "充值管理--充值审核", notes = "充值审核")
    public Result<Object> getBalanceInfoAudit(@RequestBody BalanceAuditRequest balanceAuditRequest, HttpServletRequest httpRequest) throws Exception {
        Result<Object> result = new Result<>();
        if (StringUtils.isEmpty(balanceAuditRequest.getCustomerBalanceId())) {
            return Result.error("参数不能为空！");
        }
        if (StringUtils.isEmpty(balanceAuditRequest.getAuditStatus())) {
            return Result.error("参数不能为空！");
        }
        Result<Object> dto = financeCustomerBalanceService.uptBalanceInfoAuditByid(balanceAuditRequest);
        return dto;
    }

    @PostMapping("/getAccountMoney")
    @ApiOperation(value = "充值管理--快捷充值--保存充值金额", notes = "保存充值金额")
    public Result getAccountMoney(@RequestBody BalanceQuickReq req){
        if (StringUtils.isEmpty(req.getUnifiedCreditCode())) {
            return Result.of_error("统一社会信用代码不能为空！");
        }
        if (StringUtils.isEmpty(req.getBalanceMoney())) {
            return Result.of_error("充值金额不能为空！");
        }
        Result result = new Result();
        try {
            result = financeCustomerBalanceService.uptAccountMoney(req);
        }catch (Exception e) {
            e.printStackTrace();
        }
        return result;
    }

    @PostMapping("/addCashOutMoney")
    @ApiOperation(value = "提现管理--快捷提现--保存提现金额", notes = "保存提现金额")
    public Result addCashOutMoney(@RequestBody CashOutQuickReq req){
        if (StringUtils.isEmpty(req.getUnifiedCreditCode())) {
            return Result.of_error("统一社会信用代码不能为空！");
        }
        if (StringUtils.isEmpty(req.getCashOutMoney())) {
            return Result.of_error("提现金额不能为空！");
        }
        Result result = new Result();
        try {
            result = financeCustomerBalanceService.addCashOutMoney(req);
        }catch (Exception e) {
            e.printStackTrace();
        }
        return result;
    }

    @PostMapping("/searchCompany")
    @ApiOperation(value = "充值/提现管理-搜索企业", notes = "搜索企业")
    public Result searchCompany(@RequestParam String search) {
        Result result = financeCustomerBalanceService.searchCompany(search);
        return result;
    }
}