package com.jz.manage.moduls.controller.order;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.jz.common.bean.PageInfoResponse;
import com.jz.common.constant.Constants;
import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.BaseController;
import com.jz.manage.moduls.controller.order.bean.OrderDetailDto;
import com.jz.manage.moduls.controller.order.bean.OrderDto;
import com.jz.manage.moduls.controller.order.bean.OrderRequest;
import com.jz.manage.moduls.service.OrderService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * 订单表(TOrder)表控制层
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:41
 */
@RestController
@RequestMapping("/order")
@Api(tags = "平台--订单管理--controller")
public class OrderController extends BaseController {
    /**
     * 服务对象
     */
    @Autowired
    private OrderService orderService;

    /**
     * 订单管理列表（分页查询）
     *
     * @author Bellamy
     */
    @PostMapping(value = "/list")
    @ApiOperation(value = "订单管理列表（分页查询）", notes = "订单列表（分页查询）")
    public Result<IPage<OrderDto>> queryPageList(@RequestBody OrderRequest orderRequest, HttpServletRequest req) throws Exception {
            return orderService.queryListOrderInfo(orderRequest, req);
    }

    /**
     * 根据订单主键查询，订单详情
     *
     * @param orderId
     * @author Bellamy
     */
    @GetMapping(value = "/orderDetail")
    @ApiOperation(value = "订单详情", notes = "订单详情")
    public Result<OrderDetailDto> getOrderDetail(@RequestParam(value = "orderId") String orderId, HttpServletRequest req) throws Exception {
        Result<OrderDetailDto> result = new Result<OrderDetailDto>();
        if (StringUtils.isNotEmpty(orderId)) {
            OrderDetailDto orderDto = orderService.queryOrderDetail(orderId);
            result.setData(orderDto);
        } else {
            result.setMessage("参数为不能为空！");
        }
        return result;
    }

}