package com.jz.manage.moduls.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jz.common.bean.SysUserDto;
import com.jz.common.constant.RedisMessageConstant;
import com.jz.common.constant.ResultCode;
import com.jz.common.constant.ResultMsg;
import com.jz.common.exception.ResponseException;


import com.jz.common.utils.DateUtils;
import com.jz.common.utils.NumberUtils;
import com.jz.common.utils.Result;
import com.jz.manage.moduls.controller.customer.bean.dto.CompanyDetailsDto;
import com.jz.manage.moduls.controller.customer.bean.dto.EnterpriseAuditDto;
import com.jz.manage.moduls.controller.customer.bean.request.DepartmentAuditReq;
import com.jz.manage.moduls.controller.customer.bean.request.EnterpriseAuditRequest;

import com.jz.manage.moduls.controller.customer.bean.request.SaveCustomerRequest;

import com.jz.manage.moduls.entity.*;
import com.jz.manage.moduls.mapper.*;
import com.jz.manage.moduls.service.DepartmentService;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;


import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Map;

/**
 * 企业(TDepartment)表服务实现类
 *
 * @author Bellamy
 * @since 2020-12-01 10:41:35
 */
@Service("departmentService")
public class DepartmentServiceImpl implements DepartmentService {

    private static final Logger logger = LoggerFactory.getLogger(PlatformTradeFlowInfoServiceImpl.class);

    @Autowired
    private DepartmentDao tDepartmentDao;

    @Autowired
    private FinanceCustomerAssetsDao financeCustomerAssetsDao;

    @Autowired
    private MallCustomerDao mallCustomerDao;

    @Autowired
    private FinanceCustomerBalanceDao financeCustomerBalanceDao;

    @Autowired
    private FinanceTradeFlowDao financeTradeFlowDao;

    @Autowired
    private RedisTemplate redisTemplate;

    /**
     * 条件查询企业审核信息列表
     *
     * @param auditRequest
     * @param req
     * @return
     */
    @Override
    public Result<IPage<EnterpriseAuditDto>> findList(EnterpriseAuditRequest auditRequest, HttpServletRequest req) {
        IPage<EnterpriseAuditDto> page = new Page<>(auditRequest.getPageNum(), auditRequest.getPageSize());
        QueryWrapper<EnterpriseAuditDto> query = new QueryWrapper();

        if (org.apache.commons.lang3.StringUtils.isNotBlank(auditRequest.getSearch())){
            query.and(wrapper -> wrapper.like("t1.department_name",auditRequest.getSearch())
                    .or().like("t1.linkman",auditRequest.getSearch())
                    .or().eq("t1.telephone", auditRequest.getSearch()));
        }
        if (org.apache.commons.lang3.StringUtils.isNotBlank(auditRequest.getAuditStatus())){
            query.eq("t1.audit_status",auditRequest.getAuditStatus());
        }
        if (auditRequest.getRoleId() != null){
            query.eq("t4.role_id",auditRequest.getRoleId());
        }
        if (org.apache.commons.lang3.StringUtils.isNotBlank(auditRequest.getCreTime())){
            String startTime = auditRequest.getCreTime().substring(0, 10) + " 00:00:00";
            String endTime = auditRequest.getCreTime().substring(11, 21)+ " 23:59:59";
            query.between( "t1.cre_time",startTime, endTime);
        }
        query.eq("t1.del_flag","N");
        query.orderByDesc("t1.cre_time");
        IPage<EnterpriseAuditDto> list= tDepartmentDao.findList(page, query);
        if (list.getTotal() == 0) {
            return Result.of_error("没有待审核的企业！");
        }
        return Result.of_success(list);
    }

    /**
     * 主键获取用户企业详情信息
     * @param id
     * @return
     */
    @Override
    public Result selectById(Long id) {
        CompanyDetailsDto companyDetails = tDepartmentDao.selectById(id);
        if (companyDetails == null){
            return Result.of_success("查询失败！");
        }
        return Result.of_success(ResultMsg.SUCCESS, companyDetails);
    }

    /**
     * 企业审核信息
     *
     * @param req
     */
    @Override
    public Result  audit(DepartmentAuditReq req) {
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("department_id", req.getDepartmentId());
        queryWrapper.eq("del_flag", "N");
        // 获取企业详细信息
        Department department = tDepartmentDao.selectOne(queryWrapper);
        // 从session获取平台用户id
        SysUserDto sysUser = (SysUserDto) redisTemplate.opsForValue().get("USER_" + RedisMessageConstant.SENDTYPE_LOGIN_SYS);

        // 更新信息: 将企业审核状态改为已审核，企业信息更新
        if ("01".equals(req.getAuditStatus())) {
            // 已通过
            department.setAuditStatus("02");
            department.setAuditPerson(sysUser.getUserId() + "");
            department.setAuditTime(DateUtils.getToday());
            department.setUptTime(DateUtils.getToday());
            department.setUptPerson(sysUser.getUserId()+ "");
            tDepartmentDao.updateById(department);
            return Result.of_success("企业审核已通过!");
        }
        if ("02".equals(req.getAuditStatus())){
            // 未通过
            department.setAuditStatus("03");
            department.setAuditPerson(sysUser.getUserId() + "");
            department.setAuditTime(DateUtils.getToday());
            department.setUptTime(DateUtils.getToday());
            department.setUptPerson(sysUser.getUserId()+ "");
            department.setRejectReason(req.getRejectReason());
            tDepartmentDao.updateById(department);
            return Result.of_success("企业审核未通过!");
        }
        return Result.of_error("审核失败!");
    }

    /**
     * 添加用户
     *
     * @param
     */
    @Override
    @Transactional(rollbackFor = Exception.class, propagation = Propagation.REQUIRES_NEW)
    public Result add(SaveCustomerRequest saveCustomerReq, HttpServletRequest req) {
        // 校验信息
        Result s = userCheck(saveCustomerReq);
        boolean success = s.isSuccess();
        if (!success) {
            return Result.error("添加用户失败！");
        }
        Boolean aBoolean = saveCompany(saveCustomerReq, req);
        if (!aBoolean) {
            return Result.error("添加信息失败！");
        }
        return Result.of_success("添加用户成功！");
    }

    /**
     * 保存企业信息
     * @param saveCustomerReq
     */
    private Boolean saveCompany(SaveCustomerRequest saveCustomerReq, HttpServletRequest req) {
        Department department = new Department();
        SysUserDto sysUser = (SysUserDto) redisTemplate.opsForValue().get("USER_" + RedisMessageConstant.SENDTYPE_LOGIN_SYS);
        // 添加创建人/创建时间
        department.setCrePerson(sysUser.getUserId() + "");
        department.setCreTime(DateUtils.getToday());
        // 基本信息
        department.setDepartmentName(saveCustomerReq.getDepartmentName());
        department.setRegisteredAddress(saveCustomerReq.getRegisteredAddress());
        // 企业信息
        department.setUnifiedCreditCode(saveCustomerReq.getUnifiedCreditCode());
        department.setBusinessLicense(saveCustomerReq.getBusinessLicense());
        department.setBankAddress(saveCustomerReq.getBankAddress());
        department.setBankCardNumber(saveCustomerReq.getBankCardNumber());
        // 联系人信息
        department.setLinkman(saveCustomerReq.getLinkman());
        department.setTelephone(saveCustomerReq.getTelephone());
        // 已审核
        department.setAuditStatus("02");
        department.setAuditTime(DateUtils.getToday());
        department.setCreTime(DateUtils.getToday());
        tDepartmentDao.insert(department);
        logger.info("###################企业添加用户：企业添加成功！############################");

        // 保存信息
        if (department.getDepartmentId() != null) {
            // 保存账号信息
            MallCustomer mallCustomer = new MallCustomer();
            mallCustomer.setDepartmentId(department.getDepartmentId());
            mallCustomer.setCustomerAccount(saveCustomerReq.getCustomerAccount());
            mallCustomer.setCustomerPhone(saveCustomerReq.getCustomerPhone());
            mallCustomer.setPassword(saveCustomerReq.getPassword());
            mallCustomer.setCreTime(DateUtils.getToday());
            mallCustomer.setCustomerPoint(0L);
            mallCustomer.setCrePerson(sysUser.getUserId()+"");
            mallCustomer.setDelFlag("N");
            mallCustomerDao.insert(mallCustomer);
            logger.info("###################企业添加用户：账号信息添加成功！############################");

            // 如果充值金额不为空
            if (saveCustomerReq.getBalanceMoney() != null) {
                // 新增一条企业客户资产
                FinanceCustomerAssets assets = new FinanceCustomerAssets();
                assets.setCrePerson(mallCustomer.getCustomerId() + "");
                if (department.getDepartmentId() != null) {
                    try {
                        assets.setDepartmentId(department.getDepartmentId());
                        assets.setUseMoney(saveCustomerReq.getBalanceMoney());
                        assets.setTotalMoney(saveCustomerReq.getBalanceMoney());
                        assets.setCreTime(DateUtils.getToday());
                        assets.setCrePerson(mallCustomer.getCustomerId() + "");
                        assets.setDelFlag("N");
                        financeCustomerAssetsDao.insert(assets);
                        logger.info("###################企业添加用户：企业客户资产添加成功！############################");
                    }catch (Exception e) {
                        throw ResponseException.of(ResultCode.FAILURE, "新增企业资产失败！");
                    }
                }
                // 新增一条充值记录表
                // 获取最新的资产id
                Long assetsId = assets.getAssetsId();
                FinanceCustomerBalance balance = new FinanceCustomerBalance();
                FinanceTradeFlow flow = new FinanceTradeFlow();
                if (assetsId != null) {
                    try{
                        balance.setAssetsId(assetsId);
                        balance.setBalanceMoney(saveCustomerReq.getBalanceMoney());
                        balance.setCrePerson(mallCustomer.getCustomerId() + "");
                        balance.setCreTime(DateUtils.getToday());
                        balance.setAuditStatus("02");
                        balance.setDelFlag("N");
                        financeCustomerBalanceDao.insert(balance);
                        logger.info("###################企业添加用户：充值记录添加成功！############################");
                        flow.setAssetsId(assetsId);
                        flow.setCustomerBalanceId(balance.getCustomerBalanceId());
                        flow.setTradeFlowNumber(NumberUtils.getDealNum());
                        flow.setTradeMoney(saveCustomerReq.getBalanceMoney());
                        flow.setTradeType("02");
                        flow.setBalanceMoney(assets.getUseMoney());
                        flow.setCreTime(DateUtils.getToday());
                        flow.setCrePerson(sysUser.getUserId()+ "");
                        flow.setDelFlag("N");
                        financeTradeFlowDao.insert(flow);
                        logger.info("###################企业添加用户：企业客户交易流水添加成功！############################");
                    }catch (Exception e) {
                        throw ResponseException.of(ResultCode.FAILURE, "新增充值记录/企业客户交易流水失败！");
                    }
                }
            }
        }
        return true;
    }

    /**
     * 校验企业/账号是否存在
     * @param saveCustomerReq
     */
    private Result userCheck(SaveCustomerRequest saveCustomerReq) {
        // 校验公司是否已存在
        QueryWrapper queryWrapper = new QueryWrapper();
        queryWrapper.eq("unified_credit_code", saveCustomerReq.getUnifiedCreditCode());
        Department department = tDepartmentDao.selectOne(queryWrapper);
        // 如果为空
        if (department != null) {
            return Result.error("企业已存在！");
        }
        // 校验账号信息
        Map<String, Object> accountMap = new HashMap<>();
        accountMap.put("customerAccount", saveCustomerReq.getCustomerAccount());
        // 查询用户是否存在

        Map mapUser = new HashMap();
        if (StringUtils.isNotEmpty(saveCustomerReq.getCustomerAccount())) {
            mapUser.put("customerAccount",saveCustomerReq.getCustomerAccount());
        }
        MallCustomer customerUser = mallCustomerDao.selectByUser(mapUser);
        if (customerUser != null) {
            return Result.of_error("用户已注册！");
        }
        Map mapPhone = new HashMap();
        if (StringUtils.isNotEmpty(saveCustomerReq.getTelephone())) {
            mapPhone.put("customerPhone",saveCustomerReq.getTelephone());
        }
        MallCustomer customerPhone = mallCustomerDao.selectByUser(mapPhone);
        if (customerPhone != null) {
            return Result.of_error("手机号已注册！");
        }
        //判断角色
        MallUserRole role = mallCustomerDao.findByRoleId(customerPhone.getCustomerId());
        // 查询当前用户身份
        if (role != null && role.getRoleId().toString().split(",").length > 1) {
            return Result.of_error("已成为卖家/买家！请勿重复操作！");
        }
        if (saveCustomerReq.getRoleId().equals(role.getRoleId())) {
            return Result.of_error("已重复成为卖家/买家!请勿重复操作!");
        }
        return Result.ok();
    }
}